@@ -21,6 +21,7 @@ class ActionStatus(Enum):
 class EventType(Enum):
     VM = 'vm'
     CLUSTER = 'cluster'
+    PROJECT = 'project'
 
 
 class EventSubType(Enum):
@@ -39,4 +40,5 @@ class EventVirtualization(Enum):
     OPENSTACK = 'openstack'
     VMWARE = 'vmware'
     NUTANIX = 'nutanix'
-    OPENSHIFT = 'openshift'
\ No newline at end of file
+    OPENSHIFT = 'openshift'
+    KUBERNETES = 'kubernetes'
